@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-09-11'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-09-12'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,6 +30,7 @@ has subcommands_from_package_functions => (is=>'rw');
 has include_package_functions_match => (is=>'rw');
 has exclude_package_functions_match => (is=>'rw');
 has name => (is=>'rw');
+has summary => (is=>'rw');
 has cmdline => (is=>'rw');
 has prefer_lite => (is=>'rw');
 has enable_log => (is=>'rw');
@@ -86,7 +87,11 @@ sub munge_files {
     my $scriptname = $self->name;
     if (!$scriptname) {
         $scriptname = $self->url;
-        $scriptname =~ s!.+/!!;
+        if ($scriptname =~ m!([^/]+)/\z!) {
+            $scriptname = $1;
+        } else {
+            $scriptname =~ s!.+/!!;
+        }
         $scriptname =~ s/[^A-Za-z0-9]+/-/g;
         $scriptname =~ s/^-//;
         $scriptname = "script" if length($scriptname) == 0;
@@ -122,6 +127,7 @@ sub munge_files {
             url => $self->url,
             script_name => $scriptname,
             script_version => $self->zilla->version,
+            script_summary => $self->summary,
             interpreter_path => 'perl',
             load_module => $self->load_modules ? [split(/\s*,\s*/, $self->load_modules)] : undef,
             log => $self->enable_log,
@@ -218,7 +224,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.24 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-09-11.
+This document describes version 0.25 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-09-12.
 
 =head1 SYNOPSIS
 
@@ -310,8 +316,13 @@ Will be passed to App::GenPericmdScript::gen_perinci_cmdline_script() backend.
 
 =head2 name => str
 
-Name of script to create. Default will be taken from function name, with C<_>
-replaced to C<->.
+Name of script to create. Default will be taken from function (or package) name,
+with C<_> replaced to C<->.
+
+=head2 summary => str
+
+Will be passed to C<script_summary> in
+App::GenPericmdScript::gen_perinci_cmdline_script() backend.
 
 =head2 cmdline => str
 
